psychopy_ext.exp.Task.get_blocks — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.Task.get_blocks

`Task.` `get_blocks`()

  Finds blocks in the given column of `self.exp_plan`.

  The relevant column is stored in `self.blockcol` which is given by the user when initializing the experiment class.

  Produces a list of trial lists and trial mapping for each block. Trial mapping indicates where each trial is in the original exp_plan list.

  The output is stored in `self.blocks`.